@@ -127,11 +127,9 @@ class Release:
             countries = self._countries
 
         if not version:
-            current = self._get_current_versions(countries)
+            current = self._get_current_version(countries)
             if current:
-                releases = self._get_releases_since(
-                    max(rel["version"] for rel in current)
-                )
+                releases = self._get_releases_since(current)
             else:
                 releases = self._get_releases_since(
                     semver.VersionInfo.parse("0.1.0")
@@ -154,18 +152,18 @@ class Release:
         self._manage_youtrack_card(version, countries)
 
     def _rollback(self):
-        countries = prompt_utils.ask_multiple_choices(
-            "Which countries do you want to rollback?",
+        country = prompt_utils.ask_choices(
+            "Which country do you want to rollback?",
             self._countries,
         )
 
-        if not countries:
+        if not country:
             logger.error("You must select at least one country!")
             self._rollback()
             return
 
-        current = self._get_current_versions(countries)
-        releases = self._get_releases_before(min(rel["version"] for rel in current))
+        current = self._get_current_version(country)
+        releases = self._get_releases_before(current)
         if not releases:
             logger.error(f"No previous releases found for project {self._project}!")
             sys.exit(-1)
@@ -175,23 +173,40 @@ class Release:
         )
 
         if not prompt_utils.ask_confirm(
-            f"You're about to roll back {self._project} to version {version} in {countries}, do you confirm?",
+            f"You're about to roll back {self._project} to version {version} in {country}, do you confirm?",
             default=False,
         ):
             sys.exit(0)
 
-        self._start_deploy(version, countries, rollback=True)
+        self._start_deploy(version, country, rollback=True)
 
-    def _get_current_versions(self, countries):
-        current = self._drone.get_latest_production_deploy(countries)
-        if current:
-            logger.info(f"{self._project} current version:")
-            for c in current:
-                logger.info(f"country {c['country']}: {c['version']}")
-        else:
-            logger.warning(f"No current deploy found for {self._project}")
+    def _get_current_version(self, country):
+        # get latest 10 tags
+        tags = self._github.get_tags(self._project)[0:9]
+        # retrieve specific promotion for all tags
+        builds = []
+        for tag in tags:
+            for b in self._drone.get_builds_from_tag(tag.name):
+                if (
+                    b["event"] == "promote"
+                    and b["status"] == "success"
+                    and b["deploy_to"] == f"deploy-{country}-production"
+                    and "params" in b
+                    and "DRONE_TAG" in b["params"]
+                ):
+                    builds.append(b)
 
-        return current
+        # get latest build using build number as key
+        current_build = max(builds, key=lambda x: x["number"])
+
+        if not current_build:
+            logger.error(f"Unable to determine current version for country {country}")
+            sys.exit(1)
+
+        v = semver.VersionInfo.parse(current_build["params"]["DRONE_TAG"])
+        logger.info(f"Current version for country {country}: {v}")
+
+        return v
 
     def _create_release(self, new_version, message):
         new_release = self._repo.create_git_release(
@@ -202,7 +217,7 @@ class Release:
         if new_release:
             logger.info(f"The release has been created! Link: {new_release.html_url}")
 
-            build_number = self._drone.get_build_from_tag(new_version)
+            build_number = self._drone.get_build_number_from_tag(new_version)
             if build_number:
                 drone_url = self._drone.get_build_url(build_number)
                 logger.info(f"You can follow the build status here: {drone_url}")
